package com.wstools.jni.client;


/**
 *
 * @author wolfgang schreiber
 *
 *
 * This is a wrapper class that calls into the client functions provided by JniClient32.dll
 *
 * 
 *  Potential Errors
 *
 *      Error
 *          Exception in thread "main" java.lang.UnsatisfiedLinkError: no JniClient32 in java.library.path at java.lang.ClassLoader.loadLibrary
 *      Solution
 *          Copy JniClient32.dll into path or into project root
 *
 *      Error
 *          Exception in thread "main" java.lang.UnsatisfiedLinkError: com.wstools.jni.client.JniClient32.xxx()
 *      Solution
 *          Incorrect class name in DLL? Export as Java_com_wstools_jni_client_JniClient32_xxx
 *
 *
 *
 *
 */
public class JniClient32
{

  private           final     String        VERSION_J           = "2009.0211.2003";  // @VERSION  - do not change line! ant:upd_timestamp


  private native String  NativeGetVersion();
  private native String  NativeGetConnectedTrees();
  private native String  NativeGetConnectedServers();
  private native String  NativeGetUserByServer( String serverName );
  private native String  NativeGetUserByTree(   String treeName );
  private native String  NativeGetDefaultServer();

  


  static
  {
      try
      {
        // load JniClient32.DLL it should be in the path or in the current directory
        System.loadLibrary( "JniClient32" );
      }
      catch ( Exception e )
      {
         System.out.println( e.getMessage());
      }
  }


  /** retrieve the version of the Java wrapper and the version of the Client DLL
   *
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS) or DLL_ERROR_UNKNOWN                <br>
   *    JniClientResult.data        String[]                                        <br>
   *                                data[0] :   DLL version                         <br>
   *                                data[1] :   JAR version                         <br>
   *</pre>
   */
  public JniClientResult getVersion()
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetVersion() +  JniClientResult.SEPARATOR + VERSION_J );
     return( jniClientResult );
  }


  /** get an Array of all eDirectory trees that the client is connected to
   *
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0]..data[n]  Array of tree names
   *</pre>
   */
  public JniClientResult getConnectedTrees()
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetConnectedTrees() );
     return( jniClientResult );
  }


  /** get an Array of all NCP servers that the client is connected to
   *
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0]..data[n]  Array of server names
   *</pre>
   */
  public JniClientResult getConnectedServers()
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetConnectedServers() );
     return( jniClientResult );
  }


  /** get the user name for the selected eDirectory tree
   *
   * @param treeName
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0] user name (example: "CN=admin.O=novell")
   *</pre>
   */
  public JniClientResult getUserByTree( String treeName )
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetUserByTree( treeName ) );
     return( jniClientResult );
  }


  /** get the user name for the selected NCP server
   *
   * @param serverName
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0] user name (example: "CN=admin.O=novell")
   *</pre>
   */
  public JniClientResult getUserByServer( String serverName )
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetUserByServer( serverName ) );
     return( jniClientResult );
  }


  /** get the user name for the first eDirectory tree
   *
   *    If the user has more than one tree connection, the first tree in the list will be selected
   *
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0] user name (example: "CN=admin.O=novell")
   *</pre>
   */
  public JniClientResult getDefaultUser()
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetConnectedTrees() );
     if ( jniClientResult.cCode == JniClientResult.SUCCESS )
     {
         String treeName = jniClientResult.data[0];
         if ( treeName.length() > 0 )
         {
            jniClientResult = getUserByTree( treeName );
         }
     }
     return( jniClientResult );
  }

  /** get the default NCP server
   *
   * @return JniClientResult
   *<pre>
   *    JniClientResult.cCode       0 (SUCCESS), DLL_ERROR_UNKNOWN,  or Client32 error code
   *    JniClientResult.data        String[]
   *                                data[0] server name
   *</pre>
   */
  public JniClientResult getDefaultServer( )
  {
     JniClientResult jniClientResult = new JniClientResult( NativeGetDefaultServer());
     return( jniClientResult );
  }



}
